This module is to compare excel worksheet or workbook, then highlight either the different rows or cells on the second book and then generate the output file.

- Cheny Lioe -

Read the documentation after you install the package:
$ python -m pydoc -p 8000
Server ready at http://localhost:8000/
Server commands: [b]rowser, [q]uit
server> b
Then browse to clioecsv(package) to read documentation

Package contents: clioexlsx
compare_ws >highlight_diff_cells_comments, highlight_diff_rows
compare_wb > highlight_diff_cells_comments, highlight_diff_rows
